package cn.wps.moffice.service.doc;

import cn.wps.moffice.service.doc.Page;
import cn.wps.moffice.service.doc.print.PrintSetting;
import cn.wps.moffice.service.doc.SaveFormat;
import cn.wps.moffice.service.doc.Selection;
import cn.wps.moffice.service.doc.Shapes;

//单个文档的操作接口
interface Document
{
 	//文档是否加载成功， 不成功 不能进行相关操作；
	boolean isLoadOK();
	//关闭文档
	void close();
	
	//获取文档的完整路径
	String getPath();
	
	//获取文档的名字
	String getName();
	
	//获取文档的总页数
	int getPageCount();
	
	//获取文档第n页(索引从0开始)
	Page getPage(int n);
	
	boolean printOut(in PrintSetting setting);
	
	//保存文档(noPrompt: 如果该属性值为 True，则自动保存所有文档。如果该属性值为 False，提示用户保存自上次保存后已修改过的每篇文档。)
	boolean save(boolean noPrompt);
	
	//另存为(fileName: 文件名; saveFormat:文件格式; password:用于打开文档的密码; writePassword:用于将更改保存到文档的密码字符串)
	boolean saveAs(String fileName, in SaveFormat saveFormat, String password, String writePassword);
	
	Selection getSelection();
	
	boolean isModified();
	
	void hiddenToolBar();
	
	void hiddenMenuBar();
	
	//清稿  ：接受所有修订并另存到指定路径，原文档保持当前状态
	boolean fairCopy(String path, String password);
	
	// 打开手绘批注
	void showHandWriteComment();
	
	// 关闭手绘批注
	void closeHandWriteComment();
	
	//进入修订模式
	void enterReviseMode();
	
	//退出修订模式
	void exitReviseMode();
	
	void acceptAllRevision();
	
	void denyAllRevision();
	
	
	
	Shapes getShapes();
	
	//撤销
	void undo();
	
	//还原
	void redo();
	
	//删除文档中所有批注
	void clearAllComments();
	
}