package cn.wps.moffice.service.doc;

import cn.wps.moffice.service.doc.Font;
import cn.wps.moffice.service.doc.ParagraphFormat;
import cn.wps.moffice.service.doc.BreakType;
import cn.wps.moffice.service.doc.WordUnits;
import cn.wps.moffice.service.doc.PageSetup;
import cn.wps.moffice.service.doc.Paragraphs;
//import cn.wps.moffice.service.doc.shape.Shapes;
//import cn.wps.moffice.service.doc.shape.InlineShapes;
import cn.wps.moffice.service.doc.table.Tables;
import cn.wps.moffice.service.doc.table.Table;
import cn.wps.moffice.service.doc.table.Cells;

//Range 对象引用文档中的某一连续区域。每个 Range 对象都是通过开始和结束字符位置来定义的。
interface Range
{
	void copy();
	
	void cut();
	
	void paste();
	
	//在指定选定内容之前插入指定文本。
	void insertAfter(String text);
	
	//在指定选定内容之前插入指定文本。
	void insertBefore(String text);
	
	//将指定文本插入所选位置。
	void typeText(String text);
	
	//返回Range中的所有字符
	String getText();
	
	//插入分页符、分栏符或分节符。
	void insertBreak(in BreakType type);
	
	//向原有表添加单元格。
	//void insertCells();
	
	//在选定内容的左侧插入n列。
	void insertColumnsLeft(int n);
	
	//在选定内容的右侧插入n列。
	void insertColumnsRight(int n);
	
	//在当前选定内容上方插入n行。
	void insertRowsAbove(int n);
	
	//在当前选定内容下方插入n行。
	void insertRowsBelow(int n);
	
	//在插入点的位置插入一个新页面。
	void insertNewPage();
	
	Table insertTable(int row, int column, int styleID);
	
	//用新段落替换指定的所选内容。
	void insertParagraph();
	
	//在所选内容之后插入段落标记。
	void insertParagraphAfter();
	
	//在指定的所选内容或范围前插入一个新段落。
	void insertParagraphBefore();
	
	void delete();
	
	//选中start和end之间的内容
	void select(int start, int end);
	
	//选择包含当前选定内容的匹配单元格。
	void selectCell();
	
	//移动指定的所选内容的起始位置。
	void moveStart(in WordUnits unit, int count);
	
	//移动范围或所选内容的结束字符位置。
	void moveEnd(in WordUnits unit, int count);
	
	//把当前Range保存为图片
	//boolean saveToImage(String path);
	
	//返回一个 Cells 集合，该集合代表某个区域中的表格单元格
	Cells getCells();
	
	int getStyle();
	
	boolean setStyle(int styleID);
	
	Font getFont();
	
	ParagraphFormat getParagraphFormat();
	
	//Shapes getShapes();
	
	//InlineShapes getInlineShapes();
	
	Tables getTables();
	
	PageSetup getPageSetup();
	
	void setPageSetup(in PageSetup pageSetup);
	
	Paragraphs getParagraphs();
}