package cn.wps.moffice.service.doc.table;

import cn.wps.moffice.service.doc.ConditionCode;
import cn.wps.moffice.service.doc.ConditionalStyle;
import cn.wps.moffice.service.doc.Shading;
import cn.wps.moffice.service.doc.Borders;
import cn.wps.moffice.service.doc.Font;
import cn.wps.moffice.service.doc.ParagraphFormat;

//代表可应用于表格的单个样式。
interface TableStyle
{
	//返回一个 ConditionalStyle 对象，该对象代表表格某个部分的特殊样式格式设置。
	ConditionalStyle getConditionStyle(in ConditionCode condition);
	
	Font getFont();
	
	ParagraphFormat getParagraphFormat();
	
	//返回一个表示表样式格式的底纹格式的 Shading 对象。
	Shading getShading();
	
	//返回一个 Borders 集合，该集合代表指定 ConditionalStyle 对象的所有边框
	Borders getBorders();
	
	//返回要添加在表格的单个单元格或所有单元格内容左侧的间距（以磅为单位）。
	float getLeftPadding();
	
	//设置要添加在表格的单个单元格或所有单元格内容左侧的间距（以磅为单位）。
	void setLeftPadding(float padding);
	
	//返回要添加在表格的单个单元格或所有单元格内容上方的间距（以磅为单位）。
	float getTopPadding();
	
	//设置要添加在表格的单个单元格或所有单元格内容上方的间距（以磅为单位）。
	void setTopPadding(float padding);
	
	//返回要添加在表格的单个单元格或所有单元格内容右侧的间距（以磅为单位）。
	float getRightPadding();
	
	//设置要添加在表格的单个单元格或所有单元格内容右侧的间距（以磅为单位）。
	void setRightPadding(float padding);
	
	//返回要添加在表格的单个单元格或所有单元格内容下方的间距（以磅为单位）。
	float getBottomPadding();
	
	//设置要添加在表格的单个单元格或所有单元格内容下方的间距（以磅为单位）。
	void setBottomPadding(float padding);
	
	//返回采用表格样式的单元格的间距（以磅为单位）。
	float getSpacing();
	
	//设置采用表格样式的单元格的间距（以磅为单位）。
	void setSpacing(float spacing);
}