/**
 * 异步服务接口
 * 创建者：chenmulai
 * 创建时间: 2016-03-04
 */
package com.netca.android.ctpasscertmgr.aidl;

import com.netca.android.ctpasscertmgr.aidl.AsyncServiceCallBack;

/**
 * 异步服务接口
 */
interface AsyncService{
	/**
	 * 连接服务，会对调用App进行认证（异步）
	 * @param callback: 回调处理对象，连接结果将通过此回调返回
	 */
	void Async_ConnectService(AsyncServiceCallBack callback);

	/**
	 * 枚举密钥对名字
	 * @param keyusage: 密钥用途，1 加密；2 签名。如果传0，则不限制
	 * @return: 所有密钥对名字
	 */
	String[] GetKeyPairNames(int keyusage);

	/**
	 * 异步方式枚举密钥对名字
	 * @param keyusage: 密钥用途，1 加密；2 签名。如果传0，则不限制
	 * @return: 
	 */
	void Async_GetKeyPairNames(int callid, int keyusage);

	/**
	 * 获取指定证书
	 * @param kpname: 密钥对名字
	 * @return: 返回证书DER编码
	 */
	byte[] GetCertificate(String kpname);

	/**
	 * 获取证书信息
	 * @param cert: 证书DER编码
	 * @param type: 获取信息的类型，参照国密标准《GMT0006密码应用标识规范》证书解析项标识
	 * @return: 返回证书指定信息
	 */
	//String GetCertInfo(in byte[] cert,int type);

	/**
	 * 证书P1加密
	 * @param cert: 证书DER编码
	 * @return: 加密值
	 */
	//byte[] CertEncrypt(in byte[] cert, in byte[] data);

	/**
	 * 用私钥解密（异步）
     * @param callid: 调用序列号，用于匹配回调值
	 * @param kpname: 密钥对名字。如果传null，则自动找一个解密私钥进行解密
	 * @param cipher: 密文
	 */
	//void Async_PrvKeyDecrypt(int callid, String kpname, in byte[] cipher);

	/**
     * 对hash值进行P1签名（异步）
     * @param callid: 调用序列号，用于匹配回调值
	 * @param kpname: 密钥对名字。如果传null，则自动找一个签名私钥进行签名
     * @param data: 被签名数据
     * @param hashalg: 摘要算法，比如“SHA1”、“SHA256”、“SM3”等
     */
    void Async_PrvKeySign(int callid, String kpname, in byte[] data, String hashalg);

	/**
     * P7签名，带签名证书。签名值通过callback回调
     * @param callid: 调用序列号，用于匹配回调值
	 * @param kpname: 密钥对名字。如果传null，则自动找一个签名私钥进行签名
     * @param data: 待签名的内容
     * @param isattached: 签名值是否包含原文
     * @param tsaurl: 时间戳。如果为null，则不附带时间戳
     */
    void Async_PrvKeyCMSSign(int callid, String kpname, in byte[] data, boolean isattached, String tsaurl);

	/**
     * 对P1签名进行验证
     * @param cert: 证书DER编码
     * @param data: 被签名数据
     * @param hashalg: 摘要算法，比如“SHA1”、“SHA256”、“SM3”等
     * @param signature: 签名值
	 */
	//boolean SignatureVerify(in byte[] cert, in byte[] data, String hashalg, in byte[] signature);
     /**
     * 更新PC码
     * @param callid: 调用序列号，用于匹配回调值
     * 
     */
    void UpdatePassword(int callid);
}
