/**
 * 异步服务回调接口
 * 创建者：chenmulai
 * 创建时间: 2016-03-04
 */
package com.netca.android.ctpasscertmgr.aidl;

/**
 * 异步服务回调接口
 */
interface AsyncServiceCallBack{
	/**
     * 连接服务状态回调
     * @param errcode: 错误码。0为成功，其他为错误
     * @param errmsg: 错误信息。当errcode不为0时才有效
     */
	void ConnectedNotify(int errcode, String errmsg);

	/**
     * 读取密钥对名字回调
     * @param callid: 调用序列号，用于匹配回调值
     * @param errcode: 错误码。0为成功，其他为错误
     * @param errmsg: 错误信息。当errcode不为0时才有效
     */
    void GetKeyPairNamesNotify(int callid, int errcode, String errmsg, in String[] names);

	/**
     * 对hash值进行P1签名，签名值通过callback回调
     * @param callid: 调用序列号，用于匹配回调值
     * @param errcode: 错误码。0为成功，其他为错误
     * @param errmsg: 错误信息。当errcode不为0时才有效
     * @param signature: 签名结果
     */
    void PrvKeySignNotify(int callid, int errcode, String errmsg, in byte[] signature);

	/**
     * P7签名，带签名证书。签名值通过callback回调
     * @param callid: 调用序列号，用于匹配回调值
     * @param errcode: 错误码。0为成功，其他为错误
     * @param errmsg: 错误信息。当errcode不为0时才有效
     * @param signature: 签名结果
     */
    void CMSSignNotify(int callid, int errcode, String errmsg, in byte[] signature);
     /**
     * 更新PIN码回调
     * @param callid: 调用序列号，用于匹配回调值
     * @param errcode: 错误码。0为成功，其他为错误
     * @param errmsg: 错误信息。当errcode不为0时才有效
     */
    void UpdatePINNotify(int callid, int errcode, String errmsg);
}
